@@ -87,6 +87,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::http::StatusCode;
             use checkout_core::checkout::Checkout;
             use checkout_core::server::CreateRequest;
+            use checkout_core::store::CheckoutStore;
             use checkout_core::transaction::TransactionController;
             use checkout_core::context::Context;
             use checkout_core::context::ContextProvider;
@@ -114,6 +115,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 ctx.start_transaction().await.unwrap();
                 match Checkout::create(&mut ctx, params.currency.clone()).await {
                     Ok(co) => {
+                        ctx.set_checkout(&co.id, &co).await.unwrap();
                         ctx.commit_transaction().await.unwrap();
                         Ok(HttpResponseOk(co))
                     }
